@@ -15,12 +15,15 @@ import boto
 
 import cumulus_ds
 from cumulus_ds import connection_handler
+from cumulus_ds import terminal_size
 from cumulus_ds.exceptions import (
     InvalidTemplateException,
     HookExecutionException)
 
 LOGGER = logging.getLogger(__name__)
 
+TERMINAL_WIDTH, _ = terminal_size.get_terminal_size()
+
 
 def deploy():
     """ Ensure stack is up and running (create or update it) """
@@ -347,36 +350,58 @@ def _print_event_log_event(event):
     else:
         status = event.resource_status
 
-    print((
+    row = (
         '{timestamp:<20} | {type:<45} | '
-        '{logical_id:<42} | {status:<25}').format(
+        '{logical_id:<42} | {status:<33} ').format(
             timestamp=datetime.strftime(
                 event.timestamp,
                 '%Y-%m-%dT%H:%M:%S'),
             type=event.resource_type,
             logical_id=event.logical_resource_id,
-            status=status))
+            status=status.replace('_', ' '))
+
+    if TERMINAL_WIDTH >= 160:
+        if event.resource_status_reason:
+            reason = event.resource_status_reason
+        else:
+            reason = ''
+
+        row += '| {}'.format(reason)
+
+    print(row)
 
 
 def _print_event_log_separator():
     """ Print separator line for the event log """
-    print((
+    row = (
         '---------------------+---------------'
         '--------------------------------+----------'
         '----------------------------------+--------'
-        '------------'))
+        '------------------')
+
+    if TERMINAL_WIDTH >= 160:
+        row += '+-------------------------------------'
+
+    print(row)
 
 
 def _print_event_log_title():
     """ Print event log title row on stdout """
     _print_event_log_separator()
-    print((
+
+    row = (
         '{timestamp:<20} | {type:<45} | '
         '{logical_id:<42} | {status:<25}'.format(
             timestamp='Timestamp',
             type='Resource type',
             logical_id='Logical ID',
-            status='Status')))
+            status='Status'))
+
+    if TERMINAL_WIDTH >= 160:
+        row += '| Reason'
+
+    print(row)
+
     _print_event_log_separator()
 
 
